# Rug

* [PyPI](https://pypi.org/project/rug/)
* [documentation](https://rug.readthedocs.io/en/latest/) ![Documentation Status](https://readthedocs.org/projects/rug/badge/?version=latest)

## Changelog

### 0.1.2
* `get_dividends()` now returns dividend `amount` too

### 0.1.1
* dates are now `datetime.date` instance

### 0.1
* initial release
